@@ -20,41 +20,47 @@ use base 'PDF::Builder::Basic::PDF::String';
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 =head1 NAME
 
-PDF::Builder::Basic::PDF::Bool - A special form of 
-L<PDF::Builder::Basic::PDF::String> which holds the strings
-B<true> or B<false>
+PDF::Builder::Basic::PDF::Bool - Holds the strings B<true> or B<false>
+
+Inherits from L<PDF::Builder::Basic::PDF::String>
 
 =head1 METHODS
 
+=head2 convert
+
+    $b->convert($str)
+
 =over
 
-=item $b->convert($str)
-
 Converts a string into the string which will be stored.
 
+=back
+
 =cut
 
 sub convert {
     return $_[1] eq 'true';
 }
 
-=item $b->as_pdf()
+=head2 as_pdf
+
+    $b->as_pdf()
+
+=over
 
 Converts the value to a PDF output form.
 
+=back
+
 =cut
 
 sub as_pdf {
     return $_[0]->{'val'}? 'true': 'false';
 }
 
-=back
-
-=cut
-
 1;
