@@ -5,12 +5,14 @@ use base 'PDF::Builder::Basic::PDF::Filter';
 use strict;
 use warnings;
 
-our $VERSION = '3.023'; # VERSION
-our $LAST_UPDATE = '2.029'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 =head1 NAME
 
-PDF::Builder::Basic::PDF::Filter::RunLengthDecode - compress and uncompress stream filters for Run-Length
+PDF::Builder::Basic::PDF::Filter::RunLengthDecode - Compress and uncompress stream filters for Run-Length
+
+Inherits from L<PDF::Builder::Basic::PDF::Filter>
 
 =cut
 
