@@ -3,13 +3,14 @@ package PDF::Builder::Resource::Font::CoreFont::georgiabolditalic;
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.018'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 =head1 NAME
 
-PDF::Builder::Resource::Font::CoreFont::georgiabolditalic - font-specific information for bold weight + italic Georgia font
-(I<not> standard PDF core)
+PDF::Builder::Resource::Font::CoreFont::georgiabolditalic - Font-specific information for bold weight + italic Georgia font
+
+I<Not> a standard PDF core font
 
 =cut
 
