@@ -3,8 +3,8 @@ package PDF::Builder::Resource::UniFont;
 use strict;
 use warnings;
 
-our $VERSION = '3.023'; # VERSION
-our $LAST_UPDATE = '3.016'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 use Carp;
 use Encode qw(:all);
@@ -15,16 +15,14 @@ PDF::Builder::Resource::UniFont - Unicode Font Support
 
 =head1 METHODS
 
+=head2 new
+
+    $font = PDF::Builder::Resource::UniFont->new($pdf, @fontspecs, %opts)
+
 =over
 
-=item $font = PDF::Builder::Resource::UniFont->new($pdf, @fontspecs, %options)
-
 Returns a uni-font object.
 
-=cut
-
-=pod
-
 B<FONTSPECS:> fonts can be registered using the following hash-ref:
 
     {
@@ -50,10 +48,18 @@ B<CODESPECS:>
 B<NOTE:> if you want to register a font for the entire unicode space
 (ie. U+0000 .. U+FFFF), then simply specify a font-object without the hash-ref.
 
-Valid %options are:
+=back
 
-  '-encode' ... changes the encoding of the font from its default.
-    (see "perldoc Encode" for a list of valid tags)
+=head3 Valid options (%opts)
+
+=over
+
+=item encode
+
+Changes the encoding of the font from its default.
+See "perldoc Encode" for a list of valid tags.
+
+=back
 
 =cut
 
@@ -73,8 +79,11 @@ sub new {
     push @fonts, shift() while ref($_[0]);
 
     my %options = @_;
-    $self->{'encode'} = $options{'-encode'} if defined $options{'-encode'};
-    # note that self->encode is undefined if -encode not given!
+    # copy dashed option names to preferred undashed names
+    if (defined $options{'-encode'} && !defined $options{'encode'}) { $options{'encode'} = delete($options{'-encode'}); }
+
+    $self->{'encode'} = $options{'encode'} if defined $options{'encode'};
+    # note that self->encode is undefined if encode not given!
 
     my $font_number = 0;
     foreach my $font (@fonts) {
@@ -98,7 +107,7 @@ sub new {
 		ref($font->{'blocks'}) eq 'ARRAY') {
                 foreach my $blockspec (@{$font->{'blocks'}}) {
                     if (ref($blockspec)) {
-                        foreach my $block($blockspec->[0] .. $blockspec->[-1]) {
+                        foreach my $block ($blockspec->[0] .. $blockspec->[-1]) {
                             $self->{'block'}->{$block} = $font_number;
                         }
                     } else {
@@ -131,16 +140,52 @@ sub new {
     return $self;
 }
 
+=head2 isvirtual
+
+    $flag = $font->isvirtual()
+
+=over
+
+(No Information)
+
+=back
+
+=cut
+
 sub isvirtual { 
     return 1; 
 }
 
-sub fontlist {
-    my ($self) = @_;
+=head2 fontlist
 
-    return [@{$self->{'fonts'}}];
+    $font->fontlist()
+
+=over
+
+(No Information)
+
+=back
+
+=cut
+
+sub fontlist {
+    my $self = shift;
+
+    return [@{ $self->{'fonts'} }];
 }
 
+=head2 width
+
+    $w = $font->width($string)
+
+=over
+
+(No Information)
+
+=back
+
+=cut
+
 sub width {
     my ($self, $text) = @_;
 
@@ -173,6 +218,18 @@ sub width {
     return $width;
 }
 
+=head2 text
+
+    $font->text($string, $size, $indent)
+
+=over
+
+(No Information)
+
+=back
+
+=cut
+
 sub text {
     my ($self, $text, $size, $indent) = @_;
 
@@ -215,8 +272,4 @@ sub text {
     return $newtext;
 }
 
-=back
-
-=cut
-
 1;
